# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-PPIx-Utilities
Version:	1.001000
Release:	48.%{__distinit}%{__distvers}
Summary:	Extensions to PPI
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/PPIx-Utilities
Source0:	https://cpan.metacpan.org/authors/id/E/EL/ELLIOTJS/PPIx-Utilities-%{version}.tar.gz
BuildArch:	noarch
# Build:
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Run-time:
BuildRequires:	perl(base)
BuildRequires:	perl(Exception::Class)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(PPI) >= 1.208
BuildRequires:	perl(PPI::Document::Fragment) >= 1.208
BuildRequires:	perl(Readonly)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Tests:
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(PPI::Document) >= 1.208
BuildRequires:	perl(PPI::Dumper) >= 1.208
BuildRequires:	perl(Task::Weaken)
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More)
# Extra tests:
# PPI needed by Perl::Critic, so don't run extra tests when bootstrapping
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
%endif
# Dependencies:
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This is a collection of functions for dealing with PPI objects, many of
which originated in Perl::Critic. They are organized into modules by the
kind of PPI class they relate to, by replacing the "PPI" at the front of
the module name with "PPIx::Utilities", e.g. functionality related to
PPI::Nodes is in PPIx::Utilities::Node.

%prep
%setup -q -n PPIx-Utilities-%{version}

# Remove date-sensitive copyright.t, which also upsets Perl::Critic
# (#1139503)
rm xt/author/copyright.t
sed -i -e '/copyright\.t/d' MANIFEST

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/PPIx/
%{_mandir}/man3/PPIx::Utilities.3*
%{_mandir}/man3/PPIx::Utilities::Exception::Bug.3*
%{_mandir}/man3/PPIx::Utilities::Node.3*
%{_mandir}/man3/PPIx::Utilities::Statement.3*

%changelog
* Mon May  8 2023 Paul Howarth <paul@city-fan.org> - 1.001000-48
- Use SPDX-format license tag
- Extra tests no longer include spell checks
- Use %%license unconditionally

* Sat Jun  8 2019 Paul Howarth <paul@city-fan.org> - 1.001000-33
- Perl 5.30 rebuild

* Mon Apr 16 2018 Paul Howarth <paul@city-fan.org> - 1.001000-27
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep 23 2016 Paul Howarth <paul@city-fan.org> - 1.001000-22
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Sep  9 2014 Paul Howarth <paul@city-fan.org> - 1.001000-16
- Avoid copyright.t more forcefully, as it is now upsetting Perl::Critic too
- Run the release tests in the en_US locale for the benefit of the spellchecker
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4

* Fri Oct 26 2012 Paul Howarth <paul@city-fan.org> - 1.001000-8
- Classify buildreqs by usage

* Thu Jul 12 2012 Paul Howarth <paul@city-fan.org> - 1.001000-5
- BR: perl(Exporter), perl(PPI) ≥ 1.208, and perl(Scalar::Util)
- Run the extra tests too, unless we're bootstrapping
- BR: aspell-en, perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords),
  perl(Test::Distribution), perl(Test::Kwalitee), perl(Test::Perl::Critic),
  perl(Test::Pod) and perl(Test::Pod::Coverage) for the extra tests
- Remove explicit dependency on perl(Exporter); auto-detected with rpm ≥ 4.9
  and not needed yet on any supported distribution
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 1.001000-3
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Dec  2 2010 Paul Howarth <paul@city-fan.org> - 1.001000-1
- Update to 1.001000
  - Add support for Const::Fast to PPIx::Utilities::Statement

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.000001-1
- Initial RPM version
